@@ -13,7 +13,7 @@ from .config import Config, getmainconfig
 from .users import users
 from .plugins import plugs
 from .persist import Persist
-from .errors import NoSuchBotType, BotNotEnabled
+from .errors import NoSuchBotType, BotNotEnabled, RequireError
 from .threads import start_new_thread
 from .eventhandler import mainhandler
 from fbf.utils.name import stripname
@@ -131,12 +131,12 @@ class Fleet(Persist):
         except BotNotEnabled: logging.warn("%s (%s) bot is not enabled" % (type, name)) ; bot = None 
         except NoSuchBotType: logging.warn("no such bottype %s" % type) ; bot = None
         except Exception as ex: logging.error("%s: %s" % (name, (ex))) ; bot = None
-        if not bot: logging.error("failed to get bot %s (%s) from %s" % (type, name, whichmodule(2)))
+        if not bot: logging.error("failed to get bot %s (%s) from %s" % (type, name, whichmodule(3)))
         return bot
 
     def makebot(self, type, name, config={}, domain="", showerror=False):
         """ create a bot .. use configuration if provided. """
-        if not name: logging.error(" name is not correct: %s" % name) ; return
+        if not name: raise RequireError("name is not provided")
         if config: logging.debug('making %s (%s) bot - %s - from: %s' % (type, name, config.tojson(), whichmodule()))
         bot = None
         if not config: cfg = Config('fleet' + os.sep + stripname(name) + os.sep + 'config')
@@ -277,6 +277,7 @@ class Fleet(Persist):
 
     def boot(self, botnames=[], exclude=[]):
         if not botnames: botnames = self.getenabled(exclude)
+        if not botnames: return
         bots = self.loadall(botnames)
         todo = []
         done = []
