@@ -49,10 +49,10 @@ class Alarmitem(LazyDict):
 
     """ item holding alarm data """
 
-    def __init__(self, botname='default', i=0, nick="", ttime=time.time(), txt="", printto=None, d={}):
+    def __init__(self, botname=None, i=0, nick="", ttime=time.time(), txt="", printto=None, d={}):
         if not d: LazyDict.__init__(self)
         else: LazyDict.__init__(self, d)
-        self.botname = self.botname or botname
+        if not self.botname: self.botname = botname or "default-irc"
         self.idnr = self.idnr or i
         self.nick = self.nick or nick
         self.time = self.ttime or ttime
@@ -126,7 +126,7 @@ class Alarms(Persist):
         self.save()
         return 1
 
-## defines
+## alarm object
 
 alarms = Alarms(datadir + os.sep + 'plugs' + os.sep + 'extra' + os.sep + 'alarm' + os.sep + 'alarms.new')
    
