@@ -283,19 +283,17 @@ def handle_mpd_disable(bot, ievent):
 
 def handle_mpd_playlist(bot, ievent):
     """ no arguments - show playlist. """
-    try:
-        playlist = mpd('playlistinfo')
-        tmp = ''
-        result = []
-        for item in playlist:
-           if item[0] == 'file': 
-              if not tmp == '': result.append(tmp)
-              tmp = item[1]
-           if item[0] == 'title': tmp = item[1]
-           if item[0] == 'name': tmp = '%s: %s' % (item[1], tmp)
-        ievent.reply("\n".join(result))
-    except MPDError as e:
-        ievent.reply(str(e))
+    playlist = mpd('playlistinfo')
+    tmp = ''
+    result = []
+    for item in playlist:
+       if item[0] == 'file': 
+           if not tmp == '': result.append(tmp)
+           tmp = item[1]
+       if item[0] == 'title': tmp = item[1]
+       if item[0] == 'name': tmp = '%s: %s' % (item[1], tmp)
+    if result: ievent.reply("playlist: ", result, dot="\n")
+    else: ievent.reply("no playlist")
 
 ## mpd-lsplaylists command
 
@@ -343,7 +341,7 @@ def handle_mpd_rm(bot, ievent):
      """ arguments: <playlist> - remove playlist. """
      handle_mpd_playlist_manipulation(bot, ievent, 'rm')
 
-## mpd-np command
+## mpd-np/mpd-current command
 
 def handle_mpd_np(bot, ievent):
     """ no arguments - show current playing song. """
@@ -485,8 +483,9 @@ examples.add('mpd-add', 'add a song to the current playlist', 'mpd-add mp3/bigbe
 def handle_mpd_del(bot, ievent):
     """ arguments: <position> - remove a song from the current playlist. """
     if not ievent.args: ievent.missing('<position>') ; return
-    try: result = mpd('delete %d' % int(ievent.args[0])) ; ievent.reply(result)
-    except MPDError as e: ievent.reply(str(e))
+    result = mpd('delete %d' % int(ievent.args[0]))
+    if result: ievent.reply("result is %s " % result)
+    else: ievent.reply("no result returned")   
 
 #mpd-del <position>                            Remove a song from the current playlist
 cmnds.add('mpd-del',  handle_mpd_del,  'MPD', threaded=True)
@@ -548,7 +547,7 @@ def handle_mpd_volume(bot, ievent):
     except MPDError as e:
         ievent.reply(str(s))
 
-## mpd-toggleoption command
+## mpd-toggle command
 
 def handle_mpd_toggle_option(bot, ievent, option):
     """ arguments: <value> - toggle variable. """
@@ -572,22 +571,18 @@ def handle_mpd_toggle_option(bot, ievent, option):
 
 def handle_mpd_set_option(bot, ievent, option):
     """ arguments: <value> - set value of an option. """ 
-    try:
-        if ievent.args:
-            val = -1
-            try:    val = int(ievent.args[0])
-            except: pass
-            if val > 0: 
-                mpd('%s %s' % (option, val))
-            
-            else: 
-                ievent.reply('"off" is not 0 or positive integer' % ievent.args[0])
-                return
-        else:
-            status = MPDDict(mpd('status'))
-            ievent.reply("%s %s" % (option, status['xfade']))
-    except MPDError as e:
-        ievent.reply(str(e))
+    if ievent.args:
+        val = -1
+        try: val = int(ievent.args[0])
+        except ValueError: pass
+        if val > 0: 
+            mpd('%s %s' % (option, val))
+            ievent.reply("%s option set to %s" % (option, val))
+        else: ievent.reply('"off" is not 0 or positive integer' % ievent.args[0])
+        return
+    else:
+        status = MPDDict(mpd('status'))
+        ievent.reply("%s %s" % (option, status['xfade']))
 
 ## mpd-watchstart command
 
