@@ -4,8 +4,6 @@
 
 """ do a tour of the bot. """
 
-eventlist = ["!welcome", "FBFBOT provides functionality through the use of plugins, you can use the !list comamnd to see what plugins are available =>", "!list"]
-
 ## fbf imports
 
 from fbf.lib.commands import cmnds
@@ -15,10 +13,15 @@ from fbf.lib.examples import examples
 
 import time
 
-## dotour command
+## defines
+
+eventlist = ["!welcome", "FBFBOT provides functionality through the use of plugins, you can use the !list comamnd to see what plugins are available =>", "!list"]
+
+## tour command
 
 def handle_dotour(bot, event):
     if event.user.state.data.notour: event.reply("the tour is disabled for %s" % event.userhost) ; return
+    event.untildone = True
     event.reply("will say something every 5 seconds. you can disable this tour by typing !set notour 1")
     time.sleep(5)
     for txt in eventlist:
@@ -31,4 +34,4 @@ def handle_dotour(bot, event):
     event.done()
 
 cmnds.add("tour", handle_dotour, ["OPER", "USER", "GUEST"], threaded=True)
-examples.add("tour", "show a tour of the bot", "tour")
\ No newline at end of file
+examples.add("tour", "show a tour of the bot", "tour")
